@@ -74,6 +74,52 @@ class VariablesImport(Import):
         )
 
 
+class InvalidVariableError(Exception):
+    pass
+
+
+class VariableMatcher:
+    def __init__(self, name: str) -> None:
+        from robot.utils.normalizing import normalize
+        from robot.variables.search import VariableSearcher
+
+        self.name = name
+
+        searcher = VariableSearcher("$@&%", ignore_errors=True)
+        match = searcher.search(name)
+
+        if match.base is None:
+            raise InvalidVariableError(f"Invalid variable '{name}'")
+
+        self.base = match.base
+
+        self.normalized_name = str(normalize(self.base, "_"))
+
+    def __eq__(self, o: object) -> bool:
+        from robot.utils.normalizing import normalize
+        from robot.variables.search import VariableSearcher
+
+        if isinstance(o, VariableMatcher):
+            return o.normalized_name == self.normalized_name
+        elif isinstance(o, str):
+            searcher = VariableSearcher("$@&%", ignore_errors=True)
+            match = searcher.search(o)
+            base = match.base
+            normalized = str(normalize(base, "_"))
+            return self.normalized_name == normalized
+        else:
+            return False
+
+    def __hash__(self) -> int:
+        return hash(self.name)
+
+    def __str__(self) -> str:
+        return self.name
+
+    def __repr__(self) -> str:
+        return f"{type(self).__name__}(name={repr(self.name)})"
+
+
 class VariableDefinitionType(Enum):
     VARIABLE = "variable"
     LOCAL_VARIABLE = "local variable"
@@ -82,6 +128,7 @@ class VariableDefinitionType(Enum):
     BUILTIN_VARIABLE = "builtin variable"
     IMPORTED_VARIABLE = "imported variable"
     ENVIRONMENT_VARIABLE = "environment variable"
+    VARIABLE_NOT_FOUND = "variable not found"
 
 
 @dataclass
@@ -95,6 +142,14 @@ class VariableDefinition(SourceEntity):
 
     value: Any = None
 
+    __matcher: Optional[VariableMatcher] = None
+
+    @property
+    def matcher(self) -> VariableMatcher:
+        if self.__matcher is None:
+            self.__matcher = VariableMatcher(self.name)
+        return self.__matcher
+
     def __hash__(self) -> int:
         return hash((type(self), self.name, self.type, self.range, self.source, self.name_token))
 
@@ -160,3 +215,12 @@ class EnvironmentVariableDefinition(VariableDefinition):
 
     def __hash__(self) -> int:
         return hash((type(self), self.name, self.type))
+
+
+@dataclass
+class VariableNotFoundDefinition(VariableDefinition):
+    type: VariableDefinitionType = VariableDefinitionType.VARIABLE_NOT_FOUND
+    resolvable: bool = False
+
+    def __hash__(self) -> int:
+        return hash((type(self), self.name, self.type))
