@@ -4,7 +4,6 @@ import ast
 import asyncio
 import enum
 import itertools
-import re
 import time
 import weakref
 from collections import OrderedDict
@@ -52,12 +51,14 @@ from ..utils.variables import BUILTIN_VARIABLES
 from .entities import (
     ArgumentDefinition,
     BuiltInVariableDefinition,
+    CommandLineVariableDefinition,
     EnvironmentVariableDefinition,
     Import,
     LibraryImport,
     LocalVariableDefinition,
     ResourceImport,
     VariableDefinition,
+    VariableMatcher,
     VariablesImport,
 )
 from .imports_manager import ImportsManager
@@ -68,7 +69,6 @@ from .library_doc import (
     KeywordError,
     KeywordMatcher,
     LibraryDoc,
-    VariableMatcher,
 )
 
 DIAGNOSTICS_SOURCE_NAME = "robotcode.namespace"
@@ -212,6 +212,7 @@ class BlockVariableVisitor(AsyncVisitor):
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Arguments
 
+        args: List[str] = []
         n = cast(Arguments, node)
         arguments = n.get_tokens(RobotToken.ARGUMENT)
         for argument_token in (cast(RobotToken, e) for e in arguments):
@@ -225,17 +226,19 @@ class BlockVariableVisitor(AsyncVisitor):
                         and self.position in range_from_token(argument_token)
                         and self.position > range_from_token(argument).end
                     ):
-                        continue
+                        break
 
-                    self._results[argument.value] = ArgumentDefinition(
-                        name=argument.value,
-                        name_token=strip_variable_token(argument),
-                        line_no=argument.lineno,
-                        col_offset=argument.col_offset,
-                        end_line_no=argument.lineno,
-                        end_col_offset=argument.end_col_offset,
-                        source=self.source,
-                    )
+                    if argument.value not in args:
+                        args.append(argument.value)
+                        self._results[argument.value] = ArgumentDefinition(
+                            name=argument.value,
+                            name_token=strip_variable_token(argument),
+                            line_no=argument.lineno,
+                            col_offset=argument.col_offset,
+                            end_line_no=argument.lineno,
+                            end_col_offset=argument.end_col_offset,
+                            source=self.source,
+                        )
 
             except VariableError:
                 pass
@@ -542,6 +545,8 @@ class Namespace:
         self._import_entries: OrderedDict[Import, LibraryEntry] = OrderedDict()
         self._own_variables: Optional[List[VariableDefinition]] = None
         self._own_variables_lock = Lock()
+        self._global_variables: Optional[List[VariableDefinition]] = None
+        self._global_variables_lock = Lock()
         self._diagnostics: List[Diagnostic] = []
         self._keywords: Optional[List[KeywordDoc]] = None
         self._keywords_lock = Lock()
@@ -601,6 +606,8 @@ class Namespace:
             self._diagnostics = []
             self._finder = None
 
+            await self._reset_global_variables()
+
         self.invalidated_callback(self)
 
     @_logger.call
@@ -719,6 +726,8 @@ class Namespace:
                                 ),
                             )
 
+                    await self._reset_global_variables()
+
                     self._initialized = True
 
         return self._initialized
@@ -753,8 +762,28 @@ class Namespace:
         return cls._builtin_variables
 
     @_logger.call
-    def get_command_line_variables(self) -> List[VariableDefinition]:
-        return self.imports_manager.get_command_line_variables()
+    async def get_command_line_variables(self) -> List[VariableDefinition]:
+        return await self.imports_manager.get_command_line_variables()
+
+    async def _reset_global_variables(self) -> None:
+        async with self._global_variables_lock:
+            self._global_variables = None
+
+    async def get_global_variables(self) -> List[VariableDefinition]:
+        if self._global_variables is None:
+            async with self._global_variables_lock:
+                if self._global_variables is None:
+                    self._global_variables = list(
+                        itertools.chain(
+                            await self.get_command_line_variables(),
+                            await self.get_own_variables(),
+                            *(e.variables for e in self._resources.values()),
+                            *(e.variables for e in self._variables.values()),
+                            self.get_builtin_variables(),
+                        )
+                    )
+
+        return self._global_variables
 
     @_logger.call
     async def yield_variables(
@@ -766,29 +795,33 @@ class Namespace:
         from robot.parsing.model.blocks import Keyword, TestCase
         from robot.parsing.model.statements import Arguments
 
-        # await self.ensure_initialized()
-
         yielded: Dict[VariableMatcher, VariableDefinition] = {}
 
+        test_or_keyword_nodes = list(
+            itertools.dropwhile(lambda v: not isinstance(v, (TestCase, Keyword)), nodes if nodes else [])
+        )
+        test_or_keyword = test_or_keyword_nodes[0] if test_or_keyword_nodes else None
+
         async for var in async_chain(
             *[
-                await BlockVariableVisitor(
-                    self.source, position, isinstance(nodes[-1], Arguments) if nodes else False
-                ).get(n)
-                for n in nodes or []
-                if isinstance(n, (Keyword, TestCase))
+                (
+                    await BlockVariableVisitor(
+                        self.source, position, isinstance(test_or_keyword_nodes[-1], Arguments) if nodes else False
+                    ).get(test_or_keyword)
+                )
+                if test_or_keyword is not None
+                else []
             ],
-            [] if skip_commandline_variables else (e for e in self.get_command_line_variables()),
-            (e for e in await self.get_own_variables()),
-            *(e.variables for e in self._resources.values()),
-            *(e.variables for e in self._variables.values()),
-            (e for e in self.get_builtin_variables()),
+            await self.get_global_variables(),
         ):
-            if var.name is not None:
-                matcher = VariableMatcher(var.name)
-                if matcher not in yielded.keys():
-                    yielded[matcher] = var
-                    yield matcher, var
+
+            if var.matcher not in yielded.keys():
+                yielded[var.matcher] = var
+
+                if skip_commandline_variables and isinstance(var, CommandLineVariableDefinition):
+                    continue
+
+                yield var.matcher, var
 
     async def get_resolvable_variables(
         self, nodes: Optional[List[ast.AST]] = None, position: Optional[Position] = None
@@ -799,14 +832,6 @@ class Namespace:
             if v.has_value
         }
 
-    @_logger.call
-    async def get_variable_definitions(
-        self, nodes: Optional[List[ast.AST]] = None, position: Optional[Position] = None
-    ) -> Dict[str, VariableDefinition]:
-        await self.ensure_initialized()
-
-        return {m.name: v async for m, v in self.yield_variables(nodes, position)}
-
     @_logger.call
     async def get_variable_matchers(
         self, nodes: Optional[List[ast.AST]] = None, position: Optional[Position] = None
@@ -815,14 +840,6 @@ class Namespace:
 
         return {m: v async for m, v in self.yield_variables(nodes, position)}
 
-    _match_extended = re.compile(
-        r"""
-        (.+?)          # base name (group 1)
-        ([^\s\w].+)    # extended part (group 2)
-        """,
-        re.UNICODE | re.VERBOSE,
-    )
-
     @_logger.call
     async def find_variable(
         self,
@@ -1006,6 +1023,8 @@ class Namespace:
                         source=DIAGNOSTICS_SOURCE_NAME,
                         code=type(e).__qualname__,
                     )
+            finally:
+                await self._reset_global_variables()
 
             return result, variables
 
