@@ -54,6 +54,7 @@ from ..utils.ast import (
     get_nodes_at_position,
     get_tokens_at_position,
     range_from_token,
+    tokenize_variables,
     whitespace_at_begin_of_token,
     whitespace_from_begin_of_token,
 )
@@ -410,7 +411,7 @@ class CompletionCollector(ModelHelperMixin):
                 ),
                 filter_text=s.name[2:-1] if range is not None else None,
             )
-            for s in (await self.namespace.get_variable_matchers(nodes, position)).values()
+            for s in (await self.namespace.get_variable_matchers(list(reversed(nodes)), position)).values()
             if s.name is not None and (s.name_token is None or not position.is_in_range(range_from_token(s.name_token)))
         ]
 
@@ -649,6 +650,21 @@ class CompletionCollector(ModelHelperMixin):
 
         return result
 
+    def get_variable_token(self, token: Token) -> Optional[Token]:
+        from robot.parsing.lexer.tokens import Token as RobotToken
+
+        return next(
+            (
+                v
+                for v in itertools.dropwhile(
+                    lambda t: t.type in RobotToken.NON_DATA_TOKENS,
+                    tokenize_variables(token, ignore_errors=True),
+                )
+                if v.type == RobotToken.VARIABLE
+            ),
+            None,
+        )
+
     async def complete_default(
         self,
         nodes_at_position: List[ast.AST],
@@ -667,7 +683,7 @@ class CompletionCollector(ModelHelperMixin):
                 only_stars = value is not None and "*" in value and all(v == "*" for v in value)
                 if (
                     r.start.character == 0
-                    and (position.is_in_range(r) or position == r.end)
+                    and (position.is_in_range(r))
                     and (only_stars or value.startswith("*") or position.character == 0)
                 ):
                     return await self.create_section_completion_items(r)
@@ -676,22 +692,23 @@ class CompletionCollector(ModelHelperMixin):
                     ws = whitespace_at_begin_of_token(statement_node.tokens[1])
                     if ws > 0:
                         r1.end.character = r1.start.character + ws
-                        if position.is_in_range(r1) or position == r1.end:
+                        if position.is_in_range(r1):
                             r.end = r1.end
                             return await self.create_section_completion_items(r)
 
         elif position.character == 0:
             return await self.create_section_completion_items(None)
 
-        if (
-            len(nodes_at_position) > 1
-            and isinstance(nodes_at_position[0], Statement)
-            and not isinstance(nodes_at_position[0], Arguments)
-        ):
+        if len(nodes_at_position) > 1 and isinstance(nodes_at_position[0], HasTokens):
             node = nodes_at_position[0]
             tokens_at_position = get_tokens_at_position(node, position)
             token_at_position = tokens_at_position[-1]
 
+            if isinstance(node, Arguments):
+                arg = self.get_variable_token(token_at_position)
+                if arg is not None and position <= range_from_token(arg).end:
+                    return None
+
             token_at_position_index = tokens_at_position.index(token_at_position)
             while token_at_position.type in [RobotToken.EOL]:
                 token_at_position_index -= 1
@@ -765,7 +782,7 @@ class CompletionCollector(ModelHelperMixin):
             if len(statement_node.tokens) > 0:
                 token = cast(Token, statement_node.tokens[0])
                 r = range_from_token(token)
-                if position.is_in_range(r) or r.end == position:
+                if position.is_in_range(r):
                     return await self.create_settings_completion_items(r)
 
         return None
@@ -809,7 +826,7 @@ class CompletionCollector(ModelHelperMixin):
                     index += 1
                     in_assign = True
                     r = range_from_token(token)
-                    if position.is_in_range(r) or r.end == position:
+                    if position.is_in_range(r):
                         break
 
             if len(statement_node.tokens) > index:
@@ -822,7 +839,7 @@ class CompletionCollector(ModelHelperMixin):
                 ws_b = whitespace_from_begin_of_token(token)
                 r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-                if position.is_in_range(r) or r.end == position:
+                if position.is_in_range(r):
                     return await create_items(
                         in_assign,
                         in_template,
@@ -848,7 +865,7 @@ class CompletionCollector(ModelHelperMixin):
                 token = self.strip_bdd_prefix(token)
 
                 r = range_from_token(token)
-                if position.is_in_range(r) or r.end == position:
+                if position.is_in_range(r):
                     return await create_items(in_assign, in_template, r, token, position)
 
                 if len(statement_node.tokens) > index + 1:
@@ -858,7 +875,7 @@ class CompletionCollector(ModelHelperMixin):
                         return None
 
                     r.end.character += 1
-                    if position.is_in_range(r) or r.end == position:
+                    if position.is_in_range(r):
                         return await create_items(
                             in_assign, in_template, r, None if self.is_bdd_token(token) else token, position
                         )
@@ -970,7 +987,7 @@ class CompletionCollector(ModelHelperMixin):
             ws_b = whitespace_from_begin_of_token(token)
             r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     statement_node.tokens[2] if r.end == position and len(statement_node.tokens) > 2 else None,
                     position,
@@ -984,7 +1001,7 @@ class CompletionCollector(ModelHelperMixin):
             token = self.strip_bdd_prefix(token)
 
             r = range_from_token(token)
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     None if self.is_bdd_token(token) else token,
                     position,
@@ -999,7 +1016,7 @@ class CompletionCollector(ModelHelperMixin):
                 return None
 
             r.end.character += 1
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     None if self.is_bdd_token(token) else token,
                     position,
@@ -1098,7 +1115,7 @@ class CompletionCollector(ModelHelperMixin):
             ws_b = whitespace_from_begin_of_token(token)
             r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     statement_node.tokens[3] if r.end == position and len(statement_node.tokens) > 3 else None,
                     position,
@@ -1112,7 +1129,7 @@ class CompletionCollector(ModelHelperMixin):
             token = self.strip_bdd_prefix(token)
 
             r = range_from_token(token)
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     token,
                     position,
@@ -1127,7 +1144,7 @@ class CompletionCollector(ModelHelperMixin):
                 return None
 
             r.end.character += 1
-            if position.is_in_range(r) or r.end == position:
+            if position.is_in_range(r):
                 return await self.create_keyword_completion_items(
                     None if self.is_bdd_token(token) else token,
                     position,
@@ -1193,18 +1210,18 @@ class CompletionCollector(ModelHelperMixin):
 
             if len(import_node.tokens) > import_token_index + 2:
                 name_token = import_node.tokens[import_token_index + 2]
-                if not position.is_in_range(r := range_from_token(name_token)) and r.end != position:
+                if not position.is_in_range(r := range_from_token(name_token)):
                     return None
 
             elif len(import_node.tokens) > import_token_index + 1:
                 name_token = import_node.tokens[import_token_index + 1]
-                if position.is_in_range(r := range_from_token(name_token)) or r.end == position:
+                if position.is_in_range(r := range_from_token(name_token)):
                     if whitespace_at_begin_of_token(name_token) > 1:
 
                         ws_b = whitespace_from_begin_of_token(name_token)
                         r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-                        if not position.is_in_range(r) and r.end != position:
+                        if not position.is_in_range(r):
                             return None
                     else:
                         return None
@@ -1431,18 +1448,18 @@ class CompletionCollector(ModelHelperMixin):
 
         if len(import_node.tokens) > import_token_index + 2:
             name_token = import_node.tokens[import_token_index + 2]
-            if not position.is_in_range(r := range_from_token(name_token)) and r.end != position:
+            if not position.is_in_range(r := range_from_token(name_token)):
                 return None
 
         elif len(import_node.tokens) > import_token_index + 1:
             name_token = import_node.tokens[import_token_index + 1]
-            if position.is_in_range(r := range_from_token(name_token)) or r.end == position:
+            if position.is_in_range(r := range_from_token(name_token)):
                 if whitespace_at_begin_of_token(name_token) > 1:
 
                     ws_b = whitespace_from_begin_of_token(name_token)
                     r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-                    if not position.is_in_range(r) and r.end != position:
+                    if not position.is_in_range(r):
                         return None
                 else:
                     return None
@@ -1532,18 +1549,18 @@ class CompletionCollector(ModelHelperMixin):
 
         if len(import_node.tokens) > import_token_index + 2:
             name_token = import_node.tokens[import_token_index + 2]
-            if not position.is_in_range(r := range_from_token(name_token)) and r.end != position:
+            if not position.is_in_range(r := range_from_token(name_token)):
                 return None
 
         elif len(import_node.tokens) > import_token_index + 1:
             name_token = import_node.tokens[import_token_index + 1]
-            if position.is_in_range(r := range_from_token(name_token)) or r.end == position:
+            if position.is_in_range(r := range_from_token(name_token)):
                 if whitespace_at_begin_of_token(name_token) > 1:
 
                     ws_b = whitespace_from_begin_of_token(name_token)
                     r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
-                    if not position.is_in_range(r) and r.end != position:
+                    if not position.is_in_range(r):
                         return None
                 else:
                     return None
