@@ -302,7 +302,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         fixture_node = cast(Fixture, node)
 
         name_token = cast(Token, fixture_node.get_token(RobotToken.NAME))
-        if name_token is None or name_token.value is None or name_token.value in ("", "NONE"):
+        if name_token is None or name_token.value is None or name_token.value.upper() in ("", "NONE"):
             return None
 
         result = await self.get_keyworddoc_and_token_from_position(
