@@ -21,7 +21,7 @@ from ...common.lsp_types import Position
 from ..diagnostics.entities import VariableDefinition, VariableNotFoundDefinition
 from ..diagnostics.library_doc import KeywordDoc, KeywordError
 from ..diagnostics.namespace import LibraryEntry, Namespace
-from ..utils.ast_utils import (
+from ..utils.ast import (
     Token,
     is_not_variable_token,
     iter_over_keyword_names_and_owners,
@@ -249,11 +249,7 @@ class ModelHelperMixin:
             if variable_started:
                 if toknum == python_token.NAME:
                     var = await namespace.find_variable(
-                        f"${{{tokval}}}",
-                        nodes,
-                        position,
-                        skip_commandline_variables=skip_commandline_variables,
-                        ignore_error=True,
+                        f"${{{tokval}}}", nodes, position, skip_commandline_variables=skip_commandline_variables
                     )
                     sub_token = RobotToken(
                         expression.type,
@@ -415,7 +411,7 @@ class ModelHelperMixin:
                 sub_token = token_or_var
                 name = sub_token.value
                 var = await namespace.find_variable(
-                    name, nodes, position, skip_commandline_variables=skip_commandline_variables, ignore_error=True
+                    name, nodes, position, skip_commandline_variables=skip_commandline_variables
                 )
                 if var is not None:
                     yield strip_variable_token(sub_token), var
@@ -435,11 +431,7 @@ class ModelHelperMixin:
                         base_name, _ = match.groups()
                         name = f"{name[0]}{{{base_name.strip()}}}"
                         var = await namespace.find_variable(
-                            name,
-                            nodes,
-                            position,
-                            skip_commandline_variables=skip_commandline_variables,
-                            ignore_error=True,
+                            name, nodes, position, skip_commandline_variables=skip_commandline_variables
                         )
                         sub_sub_token = RobotToken(sub_token.type, name, sub_token.lineno, sub_token.col_offset)
                         if var is not None:
